==> node-v0.1.30.tar.gz: node-v0.1.30/deps/v8/src/jump-target-inl.h <==
// Copyright 2009 the V8 project authors. All rights reserved.
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
//     * Neither the name of Google Inc. nor the names of its
//       contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef V8_JUMP_TARGET_INL_H_
#define V8_JUMP_TARGET_INL_H_

namespace v8 {
namespace internal {

CodeGenerator* JumpTarget::cgen() {
  return CodeGeneratorScope::Current();
}

void JumpTarget::InitializeEntryElement(int index, FrameElement* target) {
  entry_frame_->elements_[index].clear_copied();
  if (target->is_register()) {
    entry_frame_->set_register_location(target->reg(), index);
  } else if (target->is_copy()) {
    entry_frame_->elements_[target->index()].set_copied();
  }
  if (direction_ == BIDIRECTIONAL) {
    entry_frame_->elements_[index].set_number_info(NumberInfo::kUnknown);
  }
}

} }  // namespace v8::internal

#endif  // V8_JUMP_TARGET_INL_H_

==> node-v0.1.31.tar.gz: node-v0.1.31/deps/v8/src/jump-target-inl.h <==
// Copyright 2009 the V8 project authors. All rights reserved.
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
//     * Neither the name of Google Inc. nor the names of its
//       contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef V8_JUMP_TARGET_INL_H_
#define V8_JUMP_TARGET_INL_H_

namespace v8 {
namespace internal {

CodeGenerator* JumpTarget::cgen() {
  return CodeGeneratorScope::Current();
}

void JumpTarget::InitializeEntryElement(int index, FrameElement* target) {
  entry_frame_->elements_[index].clear_copied();
  if (target->is_register()) {
    entry_frame_->set_register_location(target->reg(), index);
  } else if (target->is_copy()) {
    entry_frame_->elements_[target->index()].set_copied();
  }
  if (direction_ == BIDIRECTIONAL && !target->is_copy()) {
    entry_frame_->elements_[index].set_number_info(NumberInfo::kUnknown);
  }
}

} }  // namespace v8::internal

#endif  // V8_JUMP_TARGET_INL_H_
